@@ -108,7 +108,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'Максимальные размеры аватар',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Ширина × высота (в пикселах).',
 	'MAX_FILESIZE'					=> 'Максимальный размер файла аватары',
-	'MAX_FILESIZE_EXPLAIN'			=> 'Максимальный размер файлов загружаемых аватар.',
+	'MAX_FILESIZE_EXPLAIN'			=> 'Максимальный размер файлов загружаемых аватар. Если значение равно 0, размер файла ограничен только конфигурацией PHP.',
 	'MIN_AVATAR_SIZE'				=> 'Минимальные размеры аватар',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Ширина × высота (в пикселах).',
 ));
